.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

xsort
=====

Defined in ``xtensor/xsort.hpp``

.. doxygenfunction:: xt::sort(const xexpression<E>&, placeholders::xtuph)
   :project: xtensor

.. doxygenfunction:: xt::sort(const xexpression<E>&, std::ptrdiff_t)
   :project: xtensor

.. doxygenfunction:: xt::argsort(const xexpression<E>&, placeholders::xtuph)
    :project: xtensor

.. doxygenfunction:: xt::argsort(const xexpression<E>&, std::ptrdiff_t)
    :project: xtensor

.. doxygenfunction:: xt::argmin(const xexpression<E>&)
   :project: xtensor

.. doxygenfunction:: xt::argmin(const xexpression<E>&, std::ptrdiff_t)
   :project: xtensor

.. doxygenfunction:: xt::argmax(const xexpression<E>&)
   :project: xtensor

.. doxygenfunction:: xt::argmax(const xexpression<E>&, std::ptrdiff_t)
   :project: xtensor

.. doxygenfunction:: xt::unique(const xexpression<E>&)
   :project: xtensor

.. doxygenfunction:: xt::partition(const xexpression<E>&, const C&, placeholders::xtuph)
   :project: xtensor

.. doxygenfunction:: xt::argpartition(const xexpression<E>&, const C&, placeholders::xtuph)
   :project: xtensor

.. doxygenfunction:: xt::median(E&&, std::ptrdiff_t)
   :project: xtensor
